Methods for reading MaxQuant outputs
Source:R/preprocess_MaxQuant.R, R/tidyMS_MaxQuant.R
MaxQuant.RdConvert MaxQuant outputs into tidy tables. For more details see functions listed in the see also section.
Convert MaxQuant outputs into tidy tables. For more details see functions listed in the see also section.
See also
Other MaxQuant:
tidyMQ_Evidence(),
tidyMQ_Peptides(),
tidyMQ_ProteinGroups()
Other MaxQuant:
tidyMQ_Evidence(),
tidyMQ_Peptides(),
tidyMQ_ProteinGroups()