Skip to contents

processing options R6 class

processing options R6 class

Public fields

transform

data transformation method

aggregate

protein abundance estimation method

diff_threshold

difference threshold

FDR_threshold

FDR threshold

remove_cont

should contaminants be removed

remove_decoys

should decoys be removed

pattern_decoys

decoy patterns

pattern_contaminants

pattern contaminants

nr_peptides

number of peptides

interaction

model with interactions default FALSE

model_missing

model missigness, default TRUE

model

name of the model to use "prolfqua", "SE", "ROPECA", default "prolfqua"

other

list with additional options

internal

protein IDs for internal standard normalization e.g. `internal: [P01876, P02768]` After transformation, intensities are centered relative to these proteins.

Methods

Public methods


Method clone()

The objects of this class are cloneable with this method.

Usage

ProcessingOptions$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.