R6 class representing ProlfquApp configuration
R6 class representing ProlfquApp configuration
See also
Other ProlfquAppConfig:
ExternalReader,
ProcessingOptions,
ProjectSpec,
make_DEA_config_R6(),
set_list_to_R6()
Public fields
processing_optionsProcessingOption R6 class
project_specProject Spec R6 class
softwarename of input software
prefixeither QC or DEA
zipdir_nameresults should go to zipdir_name
flat_outdirwhen TRUE, write results directly into `path` with no dated zipdir subdir (default FALSE keeps the dated layout)
pathpath to working directory
groupgroup prefix
ext_readerexternal reader configuration
Methods
Method new()
Initialize ProlfquAppConfig with processing options, project spec, and external reader
Usage
ProlfquAppConfig$new(
processing_options,
project_spec,
ext_reader,
zipdir_name = ".",
path = ".",
software = "DIANN",
prefix = "DEA",
flat_outdir = FALSE
)Arguments
processing_optionsinstance of ProcessingOptions
project_specinstance of ProjectSpec
ext_readerinstance of ExternalReader
zipdir_namewhere to store results
pathworking directory path
softwarename of input software
prefixeither QC or DEA
flat_outdirwrite results directly into `path` without a dated subdir (default FALSE)
Method get_zipdir()
Get the full path to the zip directory
When `flat_outdir` is TRUE the dated zipdir subdir is skipped and results are written directly into `path`.
Examples
r6obj_config <- ProlfquAppConfig$new(
ProcessingOptions$new(),
ProjectSpec$new(),
ExternalReader$new()
)
xx <- prolfqua::R6_extract_values(r6obj_config)
yaml::write_yaml(xx, file = file.path(tempdir(), "test.yaml"))
config <- yaml::read_yaml(file = file.path(tempdir(), "test.yaml"))
r6obj_config$set_zipdir_name()
#> [1] "DEA_20260623_vsn"
r6obj_config$get_zipdir()
#> [1] "./DEA_20260623_vsn"
r6obj_config$get_result_dir()
#> [1] "./DEA_20260623_vsn/Results_WU_"
r6obj_config$get_input_dir()
#> [1] "./DEA_20260623_vsn/Inputs_WU_"