Extracts protein annotation from a data frame, renaming columns and
auto-detecting UniProt identifiers. For new code prefer
build_protein_annot which returns a
ProteinAnnotation R6 object.
Extracts protein annotation from a data frame, renaming columns and
auto-detecting UniProt identifiers. For new code prefer
build_protein_annot which returns a
ProteinAnnotation R6 object.