Skip to contents

A list containing the mappings of software to string representations of functions and arguments. This is used to dynamically process different proteomics software outputs.

Usage

prolfqua_preprocess_functions

Format

An object of class list of length 15.