Write dataset to file in csv, tsv, or xlsx format
Source:R/R6_AnnotationProcessor.R
write_annotation_file.RdWrite dataset to file in csv, tsv, or xlsx format
Examples
ds <- data.frame(channel = c("A","B","C"), Name = NA, Subject = NA, Group = NA, Control = NA)
write_annotation_file(ds, file_path = file.path(tempdir(),"test.xlsx"))