keep track of folder paths and create them if needed
Source:R/ProjectStructure.R
ProjectStructure.Rdkeep track of folder paths and create them if needed
keep track of folder paths and create them if needed
Public fields
outpathpath
qc_dirqc results directory name
modelling_dirmodeling results directory name
project_Idproject_Id
order_Idorder_Id
workunit_Idworkunit_Id
inputDatainputFile
inputAnnotationinputAnnotation xlsx
Methods
Method new()
create ProjectStructure
Usage
ProjectStructure$new(
outpath,
project_Id,
order_Id,
workunit_Id,
inputAnnotation,
inputData,
qc_dir = "qc_results",
modelling_dir = "modelling_results"
)Examples
tmp <- ProjectStructure$new("./test_project",
project_Id = 3000,
order_Id = 6200,
workunit_Id = 23000,
inputAnnotation = ".",
inputData = "."
)
tmp$qc_path()
#> [1] "./test_project/qc_results"
tmp$modelling_path()
#> [1] "./test_project/modelling_results"
tmp$modelling_path()
#> [1] "./test_project/modelling_results"
tmp$modelling_dir
#> [1] "modelling_results"
tmp$modelling_path("second_model")
#> [1] "./test_project/modelling_results" "./test_project/second_model"
tmp$create()
#> NULL
tmp$reset()
#> NULL
unlink("./test_project", recursive = TRUE)