Mapping of software to string representations of functions and arguments Preprocess Functions Mapping
Source:R/preprocess_software.R
prolfqua_preprocess_functions.RdA list containing the mappings of software to string representations of functions and arguments. This is used to dynamically process different proteomics software outputs.